@@ -1,5 +1,5 @@
 package UNIVERSAL::require;
-$UNIVERSAL::require::VERSION = '0.11';
+$UNIVERSAL::require::VERSION = '0.18';
 
 # We do this because UNIVERSAL.pm uses CORE::require().  We're going
 # to put our own require() into UNIVERSAL and that makes an ambiguity.
@@ -8,16 +8,21 @@ BEGIN { require UNIVERSAL }
 
 package UNIVERSAL;
 
+use 5.006;
 use strict;
+use warnings;
+use Carp;
 
-use vars qw($Level);
-$Level = 0;
+# regexp for valid module name. Lifted from Module::Runtime
+my $module_name_rx = qr/[A-Z_a-z][0-9A-Z_a-z]*(?:::[0-9A-Z_a-z]+)*/;
+
+our $Level = 0;
 
 =pod
 
 =head1 NAME
 
-  UNIVERSAL::require - require() modules from a variable
+UNIVERSAL::require - require() modules from a variable
 
 =head1 SYNOPSIS
 
@@ -45,7 +50,7 @@ arcane eval() work, you can do this:
 
     $module->require;
 
-It doesn't save you much typing, but it'll make alot more sense to
+It doesn't save you much typing, but it'll make a lot more sense to
 someone who's not a ninth level Perl acolyte.
 
 =head1 Methods
@@ -73,10 +78,12 @@ sub require {
 
     $UNIVERSAL::require::ERROR = '';
 
-    die("UNIVERSAL::require() can only be run as a class method")
+    croak("UNIVERSAL::require() can only be run as a class method")
       if ref $module; 
 
-    die("UNIVERSAL::require() takes no or one arguments") if @_ > 2;
+    croak("invalid module name '$module'") if $module !~ /\A$module_name_rx\z/;
+
+    croak("UNIVERSAL::require() takes no or one arguments") if @_ > 2;
 
     my($call_package, $call_file, $call_line) = caller($Level);
 
@@ -86,7 +93,8 @@ sub require {
 
     # For performance reasons, check if its already been loaded.  This makes
     # things about 4 times faster.
-    return 1 if $INC{$file};
+    # We use the eval { } to make sure $@ is not set. See RT #44444 for details
+    return eval { 1 } if $INC{$file};
 
     my $return = eval qq{ 
 #line $call_line "$call_file"
@@ -94,7 +102,7 @@ CORE::require(\$file);
 };
 
     # Check for module load failure.
-    if( $@ ) {
+    if( !$return ) {
         $UNIVERSAL::require::ERROR = $@;
         return $return;
     }
@@ -104,14 +112,12 @@ CORE::require(\$file);
         eval qq{
 #line $call_line "$call_file"
 \$module->VERSION($want_version);
-};
-
-        if( $@ ) {
+1;
+}       or do {
             $UNIVERSAL::require::ERROR = $@;
             return 0;
-        }
+        };
     }
-
     return $return;
 }
 
@@ -147,12 +153,11 @@ sub use {
 package $call_package;
 #line $call_line "$call_file"
 \$module->import(\@imports);
-};
-
-    if( $@ ) {
+1;
+}   or do {
         $UNIVERSAL::require::ERROR = $@;
         return 0;
-    }
+    };
 
     return $return;
 }
@@ -183,6 +188,7 @@ See F<http://www.perl.com/perl/misc/Artistic.html>
 
 Michael G Schwern <schwern@pobox.com>
 
+Now maintained by Neil Bowers (NEILB).
 
 =head1 SEE ALSO
 
